# mediagrab
Python CLI to download videos from youtube

![PyPI - Version](https://img.shields.io/pypi/v/mediagrab)
![PyPI - License](https://img.shields.io/pypi/l/mediagrab)

## Installation
You can install the package using following command:
```sh
pip3 install mediagrab
```
(or)
```sh
pip install mediagrab
```

## Usage

### Getting help with command line arguments
```sh
mediagrab --help
```

### Main functionality
```sh
mediagrab <url>
```
url - link to a video from YouTube

## Development setup
Clone this repository and install packages listed in requirements.txt
```sh
pip3 install -r requirements.txt
```
